@@ -47,6 +47,7 @@ struct _GUPnPDIDLLiteResourcePrivate {
         xmlNode     *xml_node;
         GUPnPXMLDoc *xml_doc;
         xmlNs       *dlna_ns;
+        xmlNs       *pv_ns;
 
         GUPnPProtocolInfo *protocol_info;
 };
@@ -55,10 +56,11 @@ enum {
         PROP_0,
         PROP_XML_NODE,
         PROP_XML_DOC,
+        PROP_DLNA_NAMESPACE,
+        PROP_PV_NAMESPACE,
 
         PROP_URI,
         PROP_IMPORT_URI,
-        PROP_DLNA_NAMESPACE,
         PROP_PROTOCOL_INFO,
 
         PROP_SIZE,
@@ -77,7 +79,10 @@ enum {
         PROP_COLOR_DEPTH,
 
         PROP_UPDATE_COUNT,
-        PROP_TRACK_TOTAL
+        PROP_TRACK_TOTAL,
+
+        PROP_SUBTITLE_FILE_TYPE,
+        PROP_SUBTITLE_FILE_URI
 };
 
 static void
@@ -170,6 +175,9 @@ gupnp_didl_lite_resource_set_property (GObject      *object,
         case PROP_DLNA_NAMESPACE:
                 resource->priv->dlna_ns = g_value_get_pointer (value);
                 break;
+        case PROP_PV_NAMESPACE:
+                resource->priv->pv_ns = g_value_get_pointer (value);
+                break;
         case PROP_CLEAR_TEXT_SIZE:
                 gupnp_didl_lite_resource_set_cleartext_size (resource,
                                                      g_value_get_int64 (value));
@@ -226,6 +234,16 @@ gupnp_didl_lite_resource_set_property (GObject      *object,
                                         (resource,
                                          g_value_get_uint (value));
                 break;
+        case PROP_SUBTITLE_FILE_TYPE:
+                gupnp_didl_lite_resource_set_subtitle_file_type
+                                        (resource,
+                                         g_value_get_string (value));
+                break;
+        case PROP_SUBTITLE_FILE_URI:
+                gupnp_didl_lite_resource_set_subtitle_file_uri
+                                        (resource,
+                                         g_value_get_string (value));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -276,6 +294,11 @@ gupnp_didl_lite_resource_get_property (GObject    *object,
                         (value,
                          gupnp_didl_lite_resource_get_dlna_namespace (resource));
                 break;
+        case PROP_PV_NAMESPACE:
+                g_value_set_pointer
+                        (value,
+                         gupnp_didl_lite_resource_get_pv_namespace (resource));
+                break;
         case PROP_CLEAR_TEXT_SIZE:
                 g_value_set_int64
                          (value,
@@ -337,6 +360,18 @@ gupnp_didl_lite_resource_get_property (GObject    *object,
                          (value,
                           gupnp_didl_lite_resource_get_track_total (resource));
                 break;
+        case PROP_SUBTITLE_FILE_TYPE:
+                g_value_set_string
+                         (value,
+                          gupnp_didl_lite_resource_get_subtitle_file_type
+                                                (resource));
+                break;
+        case PROP_SUBTITLE_FILE_URI:
+                g_value_set_string
+                         (value,
+                          gupnp_didl_lite_resource_get_subtitle_file_uri
+                                                (resource));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -549,6 +584,24 @@ gupnp_didl_lite_resource_class_init (GUPnPDIDLLiteResourceClass *klass)
                                        G_PARAM_STATIC_NICK |
                                        G_PARAM_STATIC_BLURB));
 
+        /**
+         * GUPnPDIDLLiteResource:pv-namespace:
+         *
+         * Pointer to the PV metadata namespace registered with the
+         * resource object.
+         *
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_PV_NAMESPACE,
+                 g_param_spec_pointer ("pv-namespace",
+                                       "XML namespace",
+                                       "Pointer to the PV metadata namespace "
+                                       "registered with the resource.",
+                                       G_PARAM_READWRITE |
+                                       G_PARAM_CONSTRUCT_ONLY |
+                                       G_PARAM_STATIC_STRINGS));
+
         /**
          * GUPnPDIDLLiteResource:duration:
          *
@@ -757,6 +810,38 @@ gupnp_didl_lite_resource_class_init (GUPnPDIDLLiteResourceClass *klass)
                                            0,
                                            G_PARAM_READWRITE |
                                            G_PARAM_STATIC_STRINGS));
+
+        /**
+         * GUPnPDIDLLiteResource:subtitle-file-type:
+         *
+         * Type of external subtitle file. Usually SRT or SMI.
+         **/
+        g_object_class_install_property
+                        (object_class,
+                         PROP_SUBTITLE_FILE_TYPE,
+                         g_param_spec_string ("subtitle-file-type",
+                                              "Subtitle file type",
+                                              "Type of the external subtitle "
+                                              "file",
+                                              NULL,
+                                              G_PARAM_READWRITE |
+                                              G_PARAM_STATIC_STRINGS));
+
+        /**
+         * GUPnPDIDLLiteResource:subtitle-file-uri:
+         *
+         * Uri to external subtitle file.
+         **/
+        g_object_class_install_property
+                        (object_class,
+                         PROP_SUBTITLE_FILE_TYPE,
+                         g_param_spec_string ("subtitle-file-uri",
+                                              "Subtitle file uri",
+                                              "Uri of the external subtitle "
+                                              "file",
+                                              NULL,
+                                              G_PARAM_READWRITE |
+                                              G_PARAM_STATIC_STRINGS));
 }
 
 /**
@@ -771,7 +856,8 @@ gupnp_didl_lite_resource_class_init (GUPnPDIDLLiteResourceClass *klass)
 GUPnPDIDLLiteResource *
 gupnp_didl_lite_resource_new_from_xml (xmlNode     *xml_node,
                                        GUPnPXMLDoc *xml_doc,
-                                       xmlNs       *dlna_ns)
+                                       xmlNs       *dlna_ns,
+                                       xmlNs       *pv_ns)
 {
         GUPnPDIDLLiteResource *resource;
 
@@ -779,6 +865,7 @@ gupnp_didl_lite_resource_new_from_xml (xmlNode     *xml_node,
                              "xml-node", xml_node,
                              "xml-doc", xml_doc,
                              "dlna-namespace", dlna_ns,
+                             "pv-namespace", pv_ns,
                              NULL);
 
         return resource;
@@ -817,6 +904,24 @@ gupnp_didl_lite_resource_get_dlna_namespace (GUPnPDIDLLiteResource *resource)
         return resource->priv->dlna_ns;
 }
 
+/**
+ * gupnp_didl_lite_resource_get_pv_namespace:
+ * @resource: The #GUPnPDIDLLiteObject
+ *
+ * Get the pointer to the DLNA metadata namespace registered with the XML
+ * document containing this object.
+ *
+ * Returns: (transfer none): The pointer to DLNA namespace in XML document.
+ **/
+xmlNsPtr
+gupnp_didl_lite_resource_get_pv_namespace (GUPnPDIDLLiteResource *resource)
+{
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource), NULL);
+
+        return resource->priv->pv_ns;
+}
+
+
 /**
  * gupnp_didl_lite_resource_get_uri:
  * @resource: A #GUPnPDIDLLiteResource
@@ -1680,7 +1785,7 @@ gupnp_didl_lite_resource_set_update_count (GUPnPDIDLLiteResource *resource,
         g_object_notify (G_OBJECT (resource), "update-count");
 }
 
-/*
+/**
  * gupnp_didl_lite_resource_set_track_total:
  * @resource: A #GUPnPDIDLLiteResource
  * @track_total: The total number of tracks in this resource
@@ -1746,3 +1851,101 @@ gupnp_didl_lite_resource_unset_track_total (GUPnPDIDLLiteResource *resource)
 
         g_object_notify (G_OBJECT (resource), "track-total");
 }
+
+/**
+ * gupnp_didl_lite_resource_get_subtitle_file_uri:
+ * @resource: A #GUPnPDIDLLiteResource
+ *
+ * Returns: The content of the subtitleFileUri property or %NULL when not set.
+ *
+ * Since: 0.12.4
+ **/
+const char *
+gupnp_didl_lite_resource_get_subtitle_file_uri
+                                        (GUPnPDIDLLiteResource *resource)
+{
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource), NULL);
+
+        return xml_util_get_attribute_content (resource->priv->xml_node,
+                                               "subtitleFileUri");
+}
+
+/**
+ * gupnp_didl_lite_resource_get_subtitle_file_type:
+ * @resource: A #GUPnPDIDLLiteResource
+ *
+ * Returns: The content of the subtitleFileType property or %NULL
+ *
+ * Since: 0.12.4
+ **/
+const char *
+gupnp_didl_lite_resource_get_subtitle_file_type
+                                        (GUPnPDIDLLiteResource *resource)
+{
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource), NULL);
+
+        return xml_util_get_attribute_content (resource->priv->xml_node,
+                                               "subtitleFileType");
+}
+
+/**
+ * gupnp_didl_lite_resource_set_subtitle_file_uri:
+ * @resource: A #GUPnPDIDLLiteResource
+ * @uri: (allow-none):  An URI to an external subtitle file or %NULL to remove.
+ *
+ * Set the URI of an external subtitle file to be used with this resource.
+ * When @uri is %NULL the value is removed.
+ *
+ * Since: 0.12.4
+ **/
+void
+gupnp_didl_lite_resource_set_subtitle_file_uri
+                                        (GUPnPDIDLLiteResource *resource,
+                                         const char            *uri)
+{
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource));
+
+        if (uri == NULL)
+                xmlUnsetNsProp (resource->priv->xml_node,
+                                resource->priv->pv_ns,
+                                (unsigned char *) "subtitleFileUri");
+        else
+                xmlSetNsProp (resource->priv->xml_node,
+                              resource->priv->pv_ns,
+                              (unsigned char *) "subtitleFileUri",
+                              uri);
+
+        g_object_notify (G_OBJECT (resource), "subtitle-file-uri");
+}
+
+/**
+ * gupnp_didl_lite_resource_set_subtitle_file_type:
+ * @resource: A #GUPnPDIDLLiteResource
+ * @type: (allow-none): An URI to an external subtitle file
+ *
+ * Set the type of an external subtitle file, specified via
+ * pv:subtitleFileUri using gupnp_didl_lite_resource_set_subtitle_file_uri().
+ *
+ * When @type is %NULL the value is removed.
+ *
+ * Since: 0.12.4
+ **/
+void
+gupnp_didl_lite_resource_set_subtitle_file_type
+                                        (GUPnPDIDLLiteResource *resource,
+                                         const char            *type)
+{
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource));
+
+        if (type == NULL)
+                xmlUnsetNsProp (resource->priv->xml_node,
+                                resource->priv->pv_ns,
+                                (unsigned char *) "subtitleFileUri");
+        else
+                xmlSetNsProp (resource->priv->xml_node,
+                              resource->priv->pv_ns,
+                              (unsigned char *) "subtitleFileType",
+                              type);
+
+        g_object_notify (G_OBJECT (resource), "subtitle-file-type");
+}
